=======================================================
``psyclone.tests.psyir.backend.fortran_gen_decls_test``
=======================================================

.. automodule:: psyclone.tests.psyir.backend.fortran_gen_decls_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.fortran_gen_decls_test
